==> percona-xtrabackup-80_8.0.30-23.orig.tar.gz: percona-xtrabackup-8.0.30-23/extra/libkmip/libkmip/src/CMakeFiles/demo_destroy.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/demo_destroy.c" "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/demo_destroy.dir/demo_destroy.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "RAPIDJSON_NO_SIZETYPEDEFINE"
  "RAPIDJSON_SCHEMA_USE_INTERNALREGEX=0"
  "RAPIDJSON_SCHEMA_USE_STDREGEX=1"
  "XTRABACKUP"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "extra/rapidjson/include"
  "extra/protobuf/protobuf-3.19.4/src"
  "extra/lz4/lz4-1.9.3"
  "extra/libedit/libedit-20210910-3.1/src/editline"
  "extra/zstd/zstd-1.5.0/lib"
  "extra/zlib/zlib-1.2.12"
  "."
  "include"
  "extra/libkmip/libkmip/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtrabackup-80_8.0.32-25.orig.tar.gz: percona-xtrabackup-8.0.32-25/extra/libkmip/libkmip/src/CMakeFiles/demo_destroy.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/demo_destroy.c" "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/demo_destroy.dir/demo_destroy.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "RAPIDJSON_NO_SIZETYPEDEFINE"
  "RAPIDJSON_SCHEMA_USE_INTERNALREGEX=0"
  "RAPIDJSON_SCHEMA_USE_STDREGEX=1"
  "XTRABACKUP"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "extra/rapidjson/include"
  "extra/protobuf/protobuf-3.19.4/src"
  "extra/lz4/lz4-1.9.4/lib"
  "extra/libedit/libedit-20210910-3.1/src/editline"
  "extra/zstd/zstd-1.5.0/lib"
  "extra/zlib/zlib-1.2.13"
  "."
  "include"
  "extra/libkmip/libkmip/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
